-- WhisperAction
-- by Zreptil

--  saved variables
WAConfig = {};

-- constants
WA_ONLINE = ".*%[(.+)%]%S*"..string.sub(ERR_FRIEND_ONLINE_SS,20)
WA_OFFLINE = string.format(ERR_FRIEND_OFFLINE_S,"(.+)")
WA_NOPLAYER = string.format(ERR_CHAT_PLAYER_NOT_FOUND_S,"(.+)")
WA_PREFIX = "@WA_"
WA_SUFFIX = "@"

-- local variables
WAPlayer = nil;
WAPartyRemote = nil;
evtOrgMsg = nil;
evtOrgFC = nil;
WASkipOrgEvt = false;
doDebug = false;
WATarget = nil;
WAFollowing = nil;
WARemoteState ={};
WAPartyIndex = 1;
WAQuestWatchCheck = false;
WAQuestCompleted = 0;

-- WAPhrases and WAPermissions is updated in WA_Initialize
-- with the values of WAConfig[x]["allow"]
WAPhrases =
{
  ["requeststate"] = WA_PREFIX.."requeststate"..WA_SUFFIX;
  ["replystate"]   = WA_PREFIX.."replystate"..WA_SUFFIX;
  ["followabort"] = WA_PREFIX.."followabort"..WA_SUFFIX;
  ["followinit"] = WA_PREFIX.."followinit"..WA_SUFFIX;
}
WAPermissions = {};
WARemotePlayerOff = false;
--WAQuestWatch_Update = QuestWatch_Update;

-------------------------------------------------------------------------
--
-- recreate the saved variables
--
-------------------------------------------------------------------------
function WA_Reset(bForce)
  local playerName = UnitName("player").." of "..GetCVar("realmName");

  if ( bForce or not WAConfig[playerName] ) then
    WAConfig[playerName] =
      {
      ["Version"] = WAVarVersion;
      ["commandPlayer"] = UnitName("player");
      ["invitePlayer"] = UnitName("player");
      ["remotePlayer"] = UnitName("player");
      ["questChannel"] = "WAQuest";
      ["playmessagesound"] = 0;
      ["allow"] =
        {
        ["follow"] = 1;
        ["relGhost"] = 1;
        ["revive"] = 1;
        ["group"] = 1;
        ["quest"] = 1;
        ["questToParty"] = 1;
        ["questToChannel"] = 1;
        }
      }
  end
  WAPlayer = WAConfig[playerName];
end

-------------------------------------------------------------------------
--
-- for debugging purposes
--
-------------------------------------------------------------------------
function WA_Debug(msg)
  if ( doDebug ) and ( DEFAULT_CHAT_FRAME ) then
    DEFAULT_CHAT_FRAME:AddMessage("<WhisperActionDebug> "..msg, 1.0, 1.0, 0.0);
  end
end

-------------------------------------------------------------------------
--
-- executed when addon is loaded
--
-------------------------------------------------------------------------
function WA_OnLoad()
  WhisperAction:RegisterEvent("PLAYER_LOGIN");
  WhisperAction:RegisterEvent("AUTOFOLLOW_BEGIN");
  WhisperAction:RegisterEvent("AUTOFOLLOW_END");
  WhisperAction:RegisterEvent("ADDON_ACTION_FORBIDDEN");
  WhisperAction:RegisterEvent("ADDON_ACTION_BLOCKED");
  WhisperAction:RegisterEvent("QUEST_WATCH_UPDATE");
  WhisperAction:RegisterEvent("QUEST_LOG_UPDATE");
  -- quest actions
  WhisperAction:RegisterEvent("UI_INFO_MESSAGE");

  SlashCmdList["WHISPERACTION"] = function(msg) WA_SlashHandler(msg) end;
  SLASH_WHISPERACTION1 = "/whisperaction";
  SLASH_WHISPERACTION2 = "/wa";
  SlashCmdList["WHISPERACTIONRL"] = function() WA_ReloadUI() end;
	SLASH_WHISPERACTIONRL1 = "/rl";

  if ( FC_ChatFrame_OnEvent ) then
    evtOrgFC = FC_ChatFrame_OnEvent;
    FC_ChatFrame_OnEvent = WA_FCHandler;
  end

  evtOrgMsg = ChatFrame_MessageEventHandler;
  ChatFrame_MessageEventHandler = WA_MsgHandler;
end

-------------------------------------------------------------------------
--
-- initialization
--
-------------------------------------------------------------------------
function WA_Initialize()
  local playerName = UnitName("player").." of "..GetCVar("realmName");

  if      ( WAConfig[playerName] )
      and (   ( not WAConfig[playerName].Version )
           or ( WAConfig[playerName].Version ~= WAVarVersion )
          )
    then
    WA_Reset(true);
    message(WAMessaged["defaultload"]);
  else
    WA_Reset(false);
  end


  WAPlayer = WAConfig[playerName];

  table.foreach(WAPlayer["allow"],
    function(k,v)
      WAPhrases[k]=WA_PREFIX..k..WA_SUFFIX;
      WAPermissions[k]=1;
      end);

  WA_ReplyState();


  if WAPlayer.allow["questToChannel"] == 1 then
    JoinChannelByName(WAPlayer.questChannel);
  end

  return WAPlayer;
end

-------------------------------------------------------------------------
--
-- eventhandler
--
-------------------------------------------------------------------------
function WA_OnEvent(self,event,...)
  local arg1, arg2, arg3, arg4 = ...
  if event == "PLAYER_LOGIN" then
    local playerName = UnitName("player");
    if ( playerName ~= UNKNOWNBEING ) and ( playerName ~= "Unknown Entity" ) and ( WAPlayer == nil ) then
      WA_Chat(WAMessages["loaded"]);
      WA_Initialize();
    end
  elseif ( event == "AUTOFOLLOW_BEGIN" ) then
		if WAFollowing == nil then
			WAFollowing = arg1;
      WA_Whisper("followinit");
	  end
  elseif ( event == "AUTOFOLLOW_END" ) then
		if WAFollowing ~= nil then
      WA_Whisper("followabort");
			WAFollowing = nil;
	  end
  elseif (event == "UI_INFO_MESSAGE" ) then
    WA_ProcessInfoMessage(arg1,arg2,arg3,arg4);
  elseif (event == "QUEST_LOG_UPDATE" ) then
    WA_QuestLogUpdate();
  elseif (event == "QUEST_WATCH_UPDATE" ) then
    WA_QuestWatchUpdate(arg1);
  elseif ( doDebug and event == "ADDON_ACTION_FORBIDDEN" ) then
    DEFAULT_CHAT_FRAME:AddMessage(arg1.." forbidden "..arg2);
  elseif ( doDebug and event == "ADDON_ACTION_BLOCKED" ) then
    DEFAULT_CHAT_FRAME:AddMessage(arg1.." blocked "..arg2);
  end
end

-------------------------------------------------------------------------
--
-- process the info message
--
-------------------------------------------------------------------------
function WA_ProcessInfoMessage(...)
  local arg1, arg2, arg3, arg4 = ...

  if arg1 == nil then
    return;
  end
  local QuestText = gsub(arg1,"(.*):%s*([-%d]+)%s*/%s*([-%d]+)%s*$","%1",1);
  if ( QuestText ~= arg1) then
    WA_Send(WAMessages["questprefix"]..arg1..WAMessages["questsuffix"]);
  end
end

-------------------------------------------------------------------------
--
-- a quest has been completed
--
-------------------------------------------------------------------------
function WA_QuestWatchUpdate(questId)
  WAQuestCompleted = questId;
  WAQuestWatchCheck = true;
end

-------------------------------------------------------------------------
--
-- something in the quests has changed
--
-------------------------------------------------------------------------
function WA_QuestLogUpdate()
  if WAQuestWatchCheck == true then
    WAQuestWatchCheck = false;

    local lTitle, lLevel, lTag, lGroup, isHeader, isCollapsed, isComplete, isDaily = GetQuestLogTitle(WAQuestCompleted);

    if isComplete then
      PlaySound("igQuestListComplete");
      UIErrorsFrame:AddMessage("|cff00ffff"..GetQuestLogTitle(WAQuestCompleted).." ("..WAMessages["qcomplete"]..")", 1.0, 1.0, 1.0, 1.0, 2);
      WA_Send(format(WAMessages["questcomplete"],GetQuestLogTitle(WAQuestCompleted)));
      RemoveQuestWatch(WAQuestCompleted);
      WatchFrame_Update();
    end
  end
end

-------------------------------------------------------------------------
--
-- show a message
--
-------------------------------------------------------------------------
function WA_Send(msg)
-- SAY, EMOTE, PARTY, YELL, GUILD, OFFICER, RAID, RAID_WARNING
-- BATTLEGROUND, WHISPER, CHANNEL
  if WAPlayer.allow["questToParty"] == 1 and GetNumPartyMembers() > 0 then
    SendChatMessage(msg, "PARTY");
  end
  if WAPlayer.allow["questToChannel"] == 1 then
    SendChatMessage(msg, "CHANNEL", nil, GetChannelName(WAPlayer.questChannel));
  end
end

-------------------------------------------------------------------------
--
-- eventhandler for ForgottenChat
--
-------------------------------------------------------------------------
function WA_FCHandler(event)
  WASkipOrgEvt = true;
  WA_MsgHandler(event);
  WASkipOrgEvt = false;
  evtOrgFC(event);
end

-------------------------------------------------------------------------
--
-- eventhandler
--
-------------------------------------------------------------------------
function WA_MsgHandler(self,event,...)
  local arg1, arg2, arg3, arg4 = ...
  removeFromChat = 0;

  if (    arg2 ~= UnitName("player") and
          WAPlayer ~= nil
      and WAPlayer["playmessagesound"] == 1
      and 
          (   event == "CHAT_MSG_PARTY"
           or event == "CHAT_MSG_SAY"
           or event == "CHAT_MSG_WHISPER"
           or event == "CHAT_MSG_GUILD"
           or event == "CHAT_MSG_OFFICER"
           or event == "CHAT_MSG_RAID"
           or event == "CHAT_MSG_RAID_LEADER"
           or event == "CHAT_MSG_YELL"
          )
      and WA_IsInGuild(arg2)
     ) then
    PlaySoundFile("Interface\\AddOns\\WhisperAction\\IncomingChat.mp3")
  end

  if ( event == "CHAT_MSG_WHISPER" or event == "CHAT_MSG_WHISPER_INFORM" ) then
    evt = "";
    params = "";

    if ( strsub(arg1,1,4) ~= WA_PREFIX ) then
      if ( not WASkipOrgEvt ) then
        evtOrgMsg(self,event,...);
      end
      return;
    end

    removeFromChat = 1;
    isCommander = ( arg2 == WAPlayer.commandPlayer or UnitInParty(arg2) );
    isRemote = ( arg2 == WA_GetRemotePlayer() );
    if ( arg2 ) and ( isCommander or isRemote ) then
      table.foreach(WAPhrases,function(k,v)if(strsub(arg1,1,strlen(v))==v)then evt=k; params=strsub(arg1,strlen(v)+1); end end)
      if ( evt ~= "" ) and ( event == "CHAT_MSG_WHISPER_INFORM" ) then
        return;
      end

      if ( evt ~= "" ) and ( WAPlayer.allow[evt] ~= nil ) and ( not WAPlayer.allow[evt] ) then
        return;
      end

      WA_ChangeTarget(arg2);
      if ( evt == "follow" ) and ( isCommander ) and ( WAPlayer["allow"]["follow"] == 1 ) then
          local msg = WAMessages["follow"];
          if ( UnitSex("target") == 0 ) then
            msg = WAMessages["followm"];
          elseif ( UnitSex("target") == 1 ) then
            msg = WAMessages["followf"];
          end

          WA_Chat(format(msg,arg2));
          FollowUnit(arg2);
      elseif ( evt == "relGhost" ) and ( isCommander ) and ( WAPlayer["allow"]["relGhost"] == 1 )  then
        WA_Chat(format(WAMessages["relGhost"],arg2));
        RepopMe();
      elseif ( evt == "revive" ) and ( isCommander ) and ( WAPlayer["allow"]["revive"] == 1 )  then
        WA_Chat(format(WAMessages["revive"],arg2));
        RepopMe();
        AcceptResurrect();
      elseif ( evt == "group" ) and ( isCommander ) and ( WAPlayer["allow"]["group"] == 1 ) then
        AcceptGroup();
        if ( UnitInParty("target") ) then
          WA_Chat(format(WAMessages["group"],arg2));
        end
      elseif ( evt == "quest" ) and ( isCommander ) and ( WAPlayer["allow"]["quest"] == 1 ) then
        AcceptQuest();
        WA_Chat(format(WAMessages["quest"],arg2));
      elseif ( evt == "requeststate" ) and ( isCommander ) then
        WA_ReplyState();
      elseif ( evt == "replystate" ) and ( isRemote ) then
        table.foreach(WAPlayer["allow"],function(k,v)WARemoteState[k]=v; end);
        WARemotePlayerOff = false;
        WA_UpdateRC();
      elseif ( evt == "followabort" ) and ( isRemote ) then
        if WA_GetRemotePlayer() ~= nil then
          WA_Chat(format(WAMessages["followabort"],WA_GetRemotePlayer()));
        end
      elseif ( evt == "followinit" ) and ( isRemote ) then
        if WA_GetRemotePlayer() ~= nil then
          WA_Chat(format(WAMessages["followinit"],WA_GetRemotePlayer()));
        end
      end
      WA_RestoreTarget();
    end
  elseif event == "CHAT_MSG_SYSTEM" or event == "CHAT_MSG" then
    if WA_CheckString(arg1,WA_GetInvitePlayer(),WA_ONLINE) then
      PlaySoundFile("Interface\\AddOns\\WhisperAction\\RemoteEnter.mp3");
      InviteUnit(WA_GetInvitePlayer());
    elseif WA_CheckString(arg1,WA_GetRemotePlayer(),WA_ONLINE) then
      WA_Whisper("requeststate");
      WARemotePlayerOff = false;
      WA_UpdateRC();
    elseif WA_CheckString(arg1,WA_GetRemotePlayer(),WA_NOPLAYER) then
      if WA_GetRemotePlayer() ~= nil then
        WA_Chat(format(WAMessages["noplayer"],WA_GetRemotePlayer()));
        WARemotePlayerOff = true;
        removeFromChat = 1;
        WA_UpdateRC();
      end
    end
  end

  if removeFromChat == 0 and not WASkipOrgEvt then
    return evtOrgMsg(self,event,...);
  end
end

-------------------------------------------------------------------------
--
-- check if player is in guild
--
-------------------------------------------------------------------------
function WA_IsInGuild(player)
  local total = GetNumGuildMembers(true)
  for i = 1, total do
    local name, rank, rankIndex, level, class, zone, note, officernote, online, status, classFileName = GetGuildRosterInfo(i)
    if name == player then
      return true
    end
  end
  return false
end

-------------------------------------------------------------------------
--
-- ask remote player for stateinformation
--
-------------------------------------------------------------------------
function WA_ReplyState()
  WA_UpdateRC();
  answer = WAPhrases["replystate"];
  table.foreach(WAPlayer["allow"],function(k,v)answer=answer..v end);
  if WAPlayer.commandPlayer ~= nil and WAPlayer.commandPlayer ~= "" then
    SendChatMessage(answer,"WHISPER",GetDefaultLanguage("player"),WAPlayer.commandPlayer);
  end
end

-------------------------------------------------------------------------
--
-- check if string contains online message for given player
--
-------------------------------------------------------------------------
function WA_CheckString(text,search,regex)
  if text == nil then
    return nil;
  end

  local _, _, found = string.find(text,regex);
  return found == search;
end

-------------------------------------------------------------------------
--
-- change the target to the player with the given name
--
-------------------------------------------------------------------------
function WA_ChangeTarget(name)
--  WATarget = UnitName("target");
--  TargetByName(name);
end

-------------------------------------------------------------------------
--
-- change the target to the player with the given name
--
-------------------------------------------------------------------------
function WA_RestoreTarget()
--  if ( WATarget == nil ) then
--    ClearTarget();
--  else
--    TargetByName(WATarget);
--  end
end

-------------------------------------------------------------------------
--
-- reloads the ui
--
-------------------------------------------------------------------------
function WA_ReloadUI()
	ReloadUI()
end

-------------------------------------------------------------------------
--
-- executed when a slashcommand is entered
--
-------------------------------------------------------------------------
function WA_SlashHandler(msg)
  if ( strlen(msg) == 0 ) then
    WA_Chat(WAMessages["slashhelp"])
    return
  end

  if ( strsub(msg,1,5) == "debug" ) then
    doDebug = not doDebug
  elseif ( msg == "reset" ) then
    WA_Reset(true)
  elseif ( msg == "quests" ) then
    WA_ShowQuestInfo()
  end
end


function WA_ShowQuestInfo()
  for i = 1, GetNumQuestLogEntries() do
    local lTitle, lLevel, lTag, lGroup, isHeader, isCollapsed, isComplete, isDaily = GetQuestLogTitle(i);
    local lCount = GetNumQuestLeaderBoards(i)
    if isHeader == nil then
      WA_Chat("Quest: "..lTitle.." => "..lCount.." Ziele");
      if lCount ~= nil and lCount > 0 then
        for j = 1, lCount do
          local lDesc, lType, lDone = GetQuestLogLeaderBoard(j,i);
          WA_Chat("  Ziel "..j..": "..lDesc)
        end
      end
    end
  end
end

-------------------------------------------------------------------------
--
-- searches for a mount in the bags returns the first mount found
--
-------------------------------------------------------------------------
function WA_FindMountSlot()
  for iBag=0, 4 do
    iCount = GetContainerNumSlots(iBag);
    for iSlot=0, iCount do
      local texture = GetContainerItemInfo(iBag,iSlot);
      if ( texture ) and ( strfind(texture,"_Mount_") ) then
        return iBag,iSlot;
      end
    end
  end

  return nil,nil;
end

-------------------------------------------------------------------------
--
-- searches for a mount in the buffs
--
-------------------------------------------------------------------------
function WA_FindMountBuff()
  i = 0;
  while GetPlayerBuffTexture(i) ~= nil do
    if ( strfind(GetPlayerBuffTexture(i),"_Mount_") ) then
      return i;
    end
    i = i + 1;
  end

  return nil;
end

-------------------------------------------------------------------------
--
-- searches for a mount in the actionbars
--
-------------------------------------------------------------------------
function WA_FindMountAction()
  for iSlot=0,256 do
    if ( GetActionTexture(iSlot) ) and ( strfind(GetActionTexture(iSlot),"_Mount_") ) then
      return iSlot;
    end
  end

  return nil;
end

-------------------------------------------------------------------------
--
-- display a message in the normal chatwindow
--
-------------------------------------------------------------------------
function WA_Chat(msg)
  if DEFAULT_CHAT_FRAME then
    if doDebug then
      msg = "<WhisperAction> "..msg;
    end
    DEFAULT_CHAT_FRAME:AddMessage(msg,0.0,1.0,0.0);
  end
end

-------------------------------------------------------------------------
--
-- eventhandler for the button at the minimap
--
-------------------------------------------------------------------------
function WA_FrameToggle(button)
  local frame

  if button == "RightButton" then
    if _G["WARemoteControl"]:IsVisible() then
      _G["WARemoteControl"]:Hide()
    end
    frame = _G["WACfgFrame"]
  elseif button == "LeftButton" then
    if _G["WACfgFrame"]:IsVisible() then
      return
    end
    frame = _G["WARemoteControl"]
  end
  
  if frame:IsVisible() then
    frame:Hide()
  else
    frame:Show()
    WA_LoadConfig()
  end
end

-------------------------------------------------------------------------
--
-- load the value in the configdialog
--
-------------------------------------------------------------------------
function WA_LoadConfig()
  _G["editWACCommandPlayer"]:SetText(WAPlayer.commandPlayer);
  _G["editWACInvitePlayer"]:SetText(WA_GetInvitePlayer());
  _G["editWACRemotePlayer"]:SetText(WAPlayer.remotePlayer);
  _G["editWACQuestChannel"]:SetText(WAPlayer.questChannel);

  table.foreach(WAPlayer["allow"],
  function(k,v)
    local ctrl = _G["chkWAC"..WA_FirstLetterBig(k)];
    if ctrl ~= nil then
      ctrl:SetChecked(v);
    end
  end);
end

-------------------------------------------------------------------------
--
-- save values from configdialog
--
-------------------------------------------------------------------------
function WA_SaveConfig()
  local oldChannel = WAPlayer.questChannel;
  WAPlayer.commandPlayer = WA_FirstLetterBig(_G["editWACCommandPlayer"]:GetText());
  WAPlayer.invitePlayer = WA_FirstLetterBig(_G["editWACInvitePlayer"]:GetText());
  WAPlayer.remotePlayer = WA_FirstLetterBig(_G["editWACRemotePlayer"]:GetText());
  WAPlayer.questChannel = _G["editWACQuestChannel"]:GetText();

  table.foreach(WAPlayer["allow"],
  function(k,v)
    local ctrl = _G["chkWAC"..WA_FirstLetterBig(k)];
    if ( ctrl:GetChecked() ) then
      WAPlayer.allow[k] = 1;
    else
      WAPlayer.allow[k] = 0;
    end
  end);

  WA_ReplyState();

  if oldChannel ~= WAPlayer.questChannel then
    LeaveChannelByName(oldChannel);
    JoinChannelByName(WAPlayer.questChannel);
  end
end

-------------------------------------------------------------------------
--
-- make first letter of string uppercase
--
-------------------------------------------------------------------------
function WA_FirstLetterBig(text)
  return strupper(strsub(text,1,1))..strsub(text,2);
end

-------------------------------------------------------------------------
--
-- use target as commandplayer
--
-------------------------------------------------------------------------
function WA_UseTargetAsCommand()
  if ( UnitIsPlayer("target") ) then
    _G["editWACCommandPlayer"]:SetText(UnitName("target"));
  else
    message(WAMessages["targetplayer"]);
  end
end

-------------------------------------------------------------------------
--
-- use target as inviteplayer
--
-------------------------------------------------------------------------
function WA_UseTargetAsInvite()
  if ( UnitIsPlayer("target") ) then
    _G["editWACInvitePlayer"]:SetText(UnitName("target"));
  else
    message(WAMessages["targetplayer"]);
  end
end

-------------------------------------------------------------------------
--
-- use target as remoteplayer
--
-------------------------------------------------------------------------
function WA_UseTargetAsRemote()
  if ( UnitIsPlayer("target") ) then
    _G["editWACRemotePlayer"]:SetText(UnitName("target"));
  else
    message(WAMessages["targetplayer"]);
  end
end

-------------------------------------------------------------------------
--
-- send a whisper to the remoteplayer
--
-------------------------------------------------------------------------
function WA_Whisper(phrase)
  if WA_GetRemotePlayer() ~= nil and WA_GetRemotePlayer() ~= "" then
    SendChatMessage(WAPhrases[phrase],"WHISPER",GetDefaultLanguage("player"),WA_GetRemotePlayer());
    if ( WASent[phrase] ) then
      WA_Chat(format(WASent[phrase],WA_GetRemotePlayer()));
    end
  end
end

-------------------------------------------------------------------------
--
-- displays a tooltip
--
-------------------------------------------------------------------------
function WA_ShowTooltip(control)
  GameTooltip:SetOwner(control);
  GameTooltip:SetBackdropColor(0.0,0.0,0.0);
  GameTooltip:SetText(format(WAToolTips[control:GetName()],WA_GetRemotePlayer()),0.8,0.8,0.0);
  GameTooltip:Show();
end

-------------------------------------------------------------------------
--
-- reads a text from the config and sets it to the control
--
-------------------------------------------------------------------------
function WA_SetText(control)
  if not WAPlayer or _G[control] == nil then
    return;
  end

  WANames["WARTitle"] = WA_GetRemotePlayer();
  _G[control]:SetText(WANames[control]);
end

-------------------------------------------------------------------------
--
-- fill the controls on the configdialog
--
-------------------------------------------------------------------------
function WA_FillConfig()
  WA_SetText("WACTitle");
  WA_SetText("WACSave");
  WA_SetText("WACCancel");
  WA_SetText("btnWACCommandPlayer");
  WA_SetText("btnWACInvitePlayer");
  WA_SetText("btnWACRemotePlayer");
  WA_SetText("textWACCommand");
  WA_SetText("textWACInvite");
  WA_SetText("textWACRemote");

  table.foreach(WAPlayer["allow"],
    function(k,v)
      ctrl = "textWAC"..WA_FirstLetterBig(k);
      WA_SetText(ctrl);
    end);
end

-------------------------------------------------------------------------
--
-- update the controls on the remotecontrol using information requested
-- from the remote player
--
-------------------------------------------------------------------------
function WA_UpdateRC()
  WA_SetText("WARTitle");
  WA_SetText("WARClose");

  if ( WAPlayer == nil ) then
    return;
  end

  if ( WAPlayer["playmessagesound"] == 1 ) then
--    _G["WARSound"]:SetText(" |TInterface\\AddOns\\WhisperAction\\Speaker:0:0:2:0|t ");
    _G["WARSound"]:SetText("s");
  else
    _G["WARSound"]:SetText("-");
  end

  table.foreach(WAPlayer["allow"],
    function(k,v)
      ctrl = "WAR"..WA_FirstLetterBig(k);
      WA_SetText(ctrl);

--      if   ( WARemoteState[k] == 0 )
--        or ( WAPermissions[k] == 0 )
--        or ( WARemotePlayerOff )
--      then
--        _G[ctrl]:Disable();
--      else
--        _G[ctrl]:Enable();
--      end
    end);
end

-------------------------------------------------------------------------
--
-- change the setting that enables or disables the sound when a 
-- guildmember writes something
--
-------------------------------------------------------------------------
function WAChangeSound()
  if ( WAPlayer == nil ) then
    return;
  end

  if ( WAPlayer["playmessagesound"] == 1 ) then
    WAPlayer["playmessagesound"] = 0;
    PlaySound("igMainMenuOptionCheckBoxOff");
  else
    WAPlayer["playmessagesound"] = 1;
    PlaySound("igMainMenuOptionCheckBoxOn");
  end;

  WA_UpdateRC();
end

-------------------------------------------------------------------------
--
-- get the next groupmember and set him as the remote player
--
-------------------------------------------------------------------------
function WA_NextPartyMember()
  WAPartyIndex = WAPartyIndex+1;
  name, realm = UnitName("party"..WAPartyIndex);

  if ( name == nil ) then
    WAPartyIndex = 1;
  end

  WA_SetPartyPlayer();
end

-------------------------------------------------------------------------
--
-- read the partymember by index and set as remoteplayer
--
-------------------------------------------------------------------------
function WA_SetPartyPlayer()
  name, realm = UnitName("party"..WAPartyIndex);

  if ( name ~= nil ) then
    WAPartyRemote = name;
  elseif ( WAPartyIndex ~= 1 ) then
    WAPartyIndex = 1;
    WA_SetPartyPlayer();
  end

  WA_UpdateRC();
end

-------------------------------------------------------------------------
--
-- retrieve the name of the remote player
--
-------------------------------------------------------------------------
function WA_GetRemotePlayer()
  if WAPartyRemote ~= nil then
    return WAPartyRemote
  elseif WAPlayer ~= nil then
    return WAPlayer.remotePlayer
  else
    return "none"
  end
end

-------------------------------------------------------------------------
--
-- retrieve the name of the invite player
--
-------------------------------------------------------------------------
function WA_GetInvitePlayer()
  if WAPlayer ~= nil then
    return WAPlayer.invitePlayer
  else
    return "none"
  end
end
